@@ -149,11 +149,15 @@ def is_door(actor: Container):
 class DoorPatcher:
     """An API to patch doors. Call patch_door() to use. """
 
-    def __init__(self, editor: PatcherEditor) -> None:
+    def __init__(self, editor: PatcherEditor, show_shields: bool = False) -> None:
         # get actors from reference dicts
         self.editor = editor
+        self.show_shields_on_minimap = show_shields
         self.SHIELD = editor.resolve_actor_reference(_EXAMPLE_SHIELD)
 
+        if not self.show_shields_on_minimap:
+            self.remove_all_shields()
+
     def door_actor_to_type(self, door: Container, scenario: str) -> DoorType:
         """
         find's a door's DoorType
@@ -250,7 +254,8 @@ class DoorPatcher:
             link = life_comp[link_name]
             if link == '{EMPTY}':
                 continue  # skip shield if not linked
-            self.editor.remove_entity(self.editor.reference_for_link(link, scenario), "mapBlockages")
+            mapBlockages = "mapBlockages" if self.show_shields_on_minimap else None
+            self.editor.remove_entity(self.editor.reference_for_link(link, scenario), mapBlockages)
             life_comp[link_name] = '{EMPTY}'
 
     # turns the door into a power beam door
@@ -273,8 +278,9 @@ class DoorPatcher:
             life_comp[
                 "wpRightDoorShieldEntity"] = f"Root:pScenario:rEntitiesLayer:dctSublayers:default:dctActors:{shield_r.sName}"
 
-            self.update_minimap_for_shield(shield_l, door_type.shield, "L", scenario)
-            self.update_minimap_for_shield(shield_r, door_type.shield, "R", scenario)
+            if self.show_shields_on_minimap:
+                self.update_minimap_for_shield(shield_l, door_type.shield, "L", scenario)
+                self.update_minimap_for_shield(shield_r, door_type.shield, "R", scenario)
         
         # ensure assets are present
         for folder in door_type.required_asset_folders:
@@ -294,6 +300,8 @@ class DoorPatcher:
         self.editor.copy_actor_groups(scenario, door.sName, shield.sName)
         shield.oActorDefLink = f"actordef:{shield_data.actordefs[0]}"
         shield.vAng[1] = shield.vAng[1] if dir == "L" else -shield.vAng[1]
+        if (shield_data is ActorData.SHIELD_WIDE_BEAM):
+            shield.pComponents.LIFE['@type'] = 'CBeamDoorLifeComponent'
 
         return shield
 
@@ -308,3 +316,8 @@ class DoorPatcher:
         map_blockages = scenario_map.raw.Root.mapBlockages
         patched_container = shield_type.minimapData.create_map_blockage(shield.vPos, dir)
         map_blockages[shield.sName] = patched_container
+
+    def remove_all_shields(self):
+        for scenario in ["s010_cave", "s020_magma", "s030_baselab", "s040_aqua", "s050_forest", "s060_quarantine", "s070_basesanc", "s080_shipyard", "s090_skybase"]:
+            bmmap = self.editor.get_scenario_map(scenario)
+            bmmap.raw.Root.mapBlockages = Container()
\ No newline at end of file
