@@ -153,7 +153,7 @@ end
 
 
 function s090_skybase.OnSubAreaChange(old_subarea, old_actorgroup, new_subarea, new_actorgroup, disable_fade)
-
+  Scenario.UpdateProgressiveItemModels()
 end
 
 
@@ -244,6 +244,7 @@ end
 
 function s090_skybase.OnUsableCancelUse(actor)
   Scenario.ResetGlobalTeleport(actor)
+  Scenario.CheckWarpToStart(actor)
 end
 
 function s090_skybase.OnUsableUse(actor)
