@@ -20,6 +20,20 @@ function RemoteLua.SetReceivedPickups(count)
     Blackboard.SetProp(playerSection, "ReceivedPickups", "f", count)
 end
 
+exclude_function_from_logging = exclude_function_from_logging or function(_) end
+push_debug_print_override = push_debug_print_override or function() end
+pop_debug_print_override = pop_debug_print_override or function() end
+
+local orig_update = RemoteLua.Update
+if type(orig_update) == "function" then
+    function RemoteLua.Update()
+        exclude_function_from_logging("Update")
+        push_debug_print_override()
+        orig_update()
+        pop_debug_print_override()
+    end
+end
+
 Init.tNewGameInventory = TEMPLATE("new_game_inventory")
 
 Init.iNumRandoTextBoxes = TEMPLATE("textbox_count")
@@ -90,4 +104,4 @@ end)
 if not initOk then
     Game.LogWarn(0, "Init failed: " .. errorMsg)
     GUI.ShowMessage("Init failed: " .. errorMsg, true, "")
-end
\ No newline at end of file
+end
